@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: arch.h,v 1.41.2.1 2002/06/13 00:29:00 helio Exp $
+ $Id: arch.h,v 1.42.2.1 2003/01/13 10:32:43 helio Exp $
 
  ark -- archiver for the KDE project
 
@@ -196,18 +196,6 @@ protected:  // data
   int m_repairYear, m_repairMonth, m_repairTime;
 };
 
-// various functions for massaging timestamps
-namespace Utils
-{
-  int getYear(int theMonth, int thisYear, int thisMonth);
-  int getMonth(const char *strMonth);
-  QString fixYear(const char *strYear);
-
-  QString getTimeStamp(const QString &month,
-		       const QString &day,
-		       const QString &year);
-}
-
 // Column header strings
 // don't forget to change common_texts.cpp if you change something here
 #define FILENAME_STRING i18n(" Filename ")
