@@ -1,5 +1,5 @@
 /*
-    $Id: kcalc_core.cpp,v 1.59.2.1 2003/02/15 20:52:55 staikos Exp $
+    $Id: kcalc_core.cpp,v 1.59.2.2 2003/04/15 10:48:02 waba Exp $
 
     kCalculator, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -660,7 +660,7 @@ void QtCalculator::EnterNegate()
 	if(eestate)
 	{
 		QString str(display_str);
-		size_t pos = str.findRev('e');
+		int pos = str.findRev('e');
 
 		if(pos == -1)
 			return;
@@ -769,18 +769,24 @@ void QtCalculator::EnterFactorial()
 	eestate = false;
 	CALCAMNT work_amount1;
 	CALCAMNT work_amount2;
-	int incr;
 
 	MODF(DISPLAY_AMOUNT, &work_amount1);
 
-	incr = work_amount1 < 0 ? -1 : 1;
+	if (work_amount1 < 0)
+	{
+		display_error = true;
+		refresh_display = true;
+		last_input = OPERATION;
+		UpdateDisplay();
+		return;
+	}
 
-	work_amount2 = work_amount1 - incr;
+	work_amount2 = work_amount1 - 1;
 
 	while (work_amount1 != 0 && work_amount2 != 0 && !display_error)
 	{
 		work_amount1 *= work_amount2;
-		work_amount2 -= incr;
+		work_amount2--;
 		if(ISINF(work_amount1))
 		{
 			display_error = true;
