@@ -1,5 +1,5 @@
 /*
-    $Id: stats.h,v 1.3 1997/11/22 20:31:29 wuebben Exp $
+    $Id: stats.h,v 1.8 2001/12/16 00:53:32 mueller Exp $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -26,7 +26,7 @@
 #ifndef KSTATS_H
 #define KSTATS_H
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <math.h>
 #include "kcalctype.h"
 
@@ -55,20 +55,20 @@ public:
 
 private:
 
-    QList<CALCAMNT> data;
+    QPtrList<CALCAMNT> data;
     bool error_flag;
 
 };
 
-class MyList : public  QList<CALCAMNT> 
+class MyList : public  QPtrList<CALCAMNT> 
 {
 
 public:
 
-  MyList() : QList<CALCAMNT>() {};
+  MyList() : QPtrList<CALCAMNT>() {};
   
 protected:
-  int compareItems(GCI item1,GCI item2);
+  int compareItems(Item item1,Item item2);
 };
 
 
