@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kdepasswd.cpp,v 1.6 2002/08/13 09:45:47 mhunter Exp $
+ * $Id: kdepasswd.cpp,v 1.6.2.1 2003/04/22 15:10:38 waba Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -8,7 +8,8 @@
 
 #include <config.h>
 #include <stdlib.h>
-
+#include <unistd.h>
+#include <sys/types.h>
 
 #include <kapplication.h>
 #include <klocale.h>
@@ -21,7 +22,7 @@
 
 static KCmdLineOptions options[] = 
 {
-    { "user", I18N_NOOP("Change password of this user."), 0 },
+//    { "user", I18N_NOOP("Change password of this user."), 0 },
     { 0, 0, 0 }
 };
 
@@ -39,15 +40,19 @@ int main(int argc, char **argv)
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
     KApplication app;
+    bool bRoot = (getuid() == 0);
 
     QCString user;
     if (args->count())
 	user = args->arg(0);
 
     QCString oldpass;
-    int result = KDEpasswd1Dialog::getPassword(oldpass, user);
-    if (result != KDEpasswd1Dialog::Accepted)
-	exit(0);
+    if (!bRoot)
+    {
+        int result = KDEpasswd1Dialog::getPassword(oldpass);
+        if (result != KDEpasswd1Dialog::Accepted)
+	    exit(0);
+    }
 
     KDEpasswd2Dialog *dlg = new KDEpasswd2Dialog(oldpass, user);
     dlg->exec();
