@@ -1,7 +1,7 @@
 /*
  * disklist.cpp
  *
- * $Id: disklist.cpp,v 1.27.2.2 2003/05/10 21:45:00 waba Exp $
+ * $Id: disklist.cpp,v 1.27.2.4 2003/09/02 09:04:29 mlaurent Exp $
  *
  * Copyright (c) 1999 Michael Kropfberger <michael.kropfberger@gmx.net>
  *
@@ -84,7 +84,7 @@ if (NO_FS_TYPE)
        loadSettings();
        //readFSTAB();
        //readDF();
-};
+}
 
 
 /***************************************************************************
@@ -92,7 +92,8 @@ if (NO_FS_TYPE)
 **/
 DiskList::~DiskList()
 {
-};
+		delete dfProc;
+}
 
 /**
 Updated need to be disabled sometimes to avoid pulling the DiskEntry out from the popupmenu handler
@@ -160,7 +161,7 @@ QString rc;
         if (s[i] == '\\') {
             i++;
             switch(s[i]) {
-            case '\\':  // slash \\   
+            case '\\':
                rc += '\\';
                break;
             case '0': // octal 0nn
