@@ -1,6 +1,6 @@
   /*
 
-    $Id: kedit.cpp,v 1.165.2.6 2003/06/30 23:49:33 aseigo Exp $
+    $Id: kedit.cpp,v 1.165.2.7 2003/07/25 14:48:01 mlaurent Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -531,7 +531,7 @@ void TopLevel::file_insert()
 
     QString tmpfile;
     KIO::NetAccess::download( url, tmpfile );
-    int result = openFile( tmpfile, OPEN_INSERT, url.fileEncoding() );
+    int result = openFile( tmpfile, OPEN_INSERT, url.fileEncoding(), true );
     KIO::NetAccess::removeTempFile( tmpfile );
 
     if( result == KEDIT_OK )
@@ -1110,7 +1110,7 @@ int TopLevel::saveURL( const KURL& _url )
     return true;
 }
 
-int TopLevel::openFile( const QString& _filename, int _mode, const QString &encoding )
+int TopLevel::openFile( const QString& _filename, int _mode, const QString &encoding,  bool _undoAction )
 {
   QFileInfo info(_filename);
 
@@ -1148,8 +1148,14 @@ int TopLevel::openFile( const QString& _filename, int _mode, const QString &enco
   {
      eframe->clear();
   }
+  if ( ! _undoAction )
+      eframe->setUndoRedoEnabled(false);
+
   eframe->insertText( &stream );
   eframe->setModified(false);
+  if ( ! _undoAction )
+      eframe->setUndoRedoEnabled(true);
+
   return KEDIT_OK;
 
 }
