@@ -1,6 +1,6 @@
 /*
 
-    $Id: kedit.h,v 1.62 2002/08/31 09:00:13 mlaurent Exp $
+    $Id: kedit.h,v 1.62.2.1 2003/07/25 14:48:01 mlaurent Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -76,7 +76,7 @@ public:
      *
      * @return KEDIT_OK on success
      */
-    int openFile( const QString& _filename, int _mode, const QString &encoding);
+    int openFile( const QString& _filename, int _mode, const QString &encoding,  bool _undoAction = false );
 
     /**
      * Saves the edit widget to a file.
