@@ -63,13 +63,13 @@ KTextFileDialog::KTextFileDialog(const QString& startDir,
   */
 
   KAction* mEncoding = new KAction( 
-      i18n("Select encoding..."), 0,
+      i18n("Select Encoding..."), 0,
       this, SLOT( slotShowEncCombo() ), this, "encoding");
 
   mEncoding->setIcon( QString::fromLatin1("charset") );
  
   KToolBar *tb = toolBar();
-  mEncoding->plug( tb, 7 );
+  mEncoding->plug( tb, pathComboIndex() - 1 );
 }
 
 KTextFileDialog::~KTextFileDialog() {}
