@@ -1,6 +1,6 @@
     /*
 
-    $Id: main.cpp,v 1.6 2000/02/09 21:37:58 coolo Exp $
+    $Id: main.cpp,v 1.13 2002/01/09 11:30:23 winkvist Exp $
 
     Requires the Qt widget libraries, available at no cost at 
     http://www.troll.no
@@ -25,29 +25,7 @@
 
     */
 
-
-#include <qobject.h>
-#include <qstring.h>
-#include <qdatastream.h>
-#include <qmessagebox.h>
-#include <qstrlist.h> 
-#include <qtabdialog.h>
-#include <qdir.h>
-#include <qfileinfo.h>
-#include <qstring.h>
-#include <qfile.h>
-#include <qtextstream.h>
-
-
-#include <unistd.h>
-#include <stdlib.h>
-#include <signal.h>
-#include <fcntl.h>
-#include <sys/types.h>
-
-
-#include <kapp.h>
-#include <klocale.h>
+#include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 
@@ -57,14 +35,16 @@
 static const char *description = 
 	I18N_NOOP("KDE Floppy Disk utility");
 
-static const char *version = "v0.0.1";
+static const char *version = "2.0";
 
 int main( int argc, char *argv[] )
 {
   KAboutData aboutData("kfloppy", I18N_NOOP("KFloppy"),
     version, description, KAboutData::License_GPL,
-    "(c) 1997, Bernd Johannes Wuebben");
-  aboutData.addAuthor("Bernd Johannes Wuebben",0, "wuebben@math.cornell.edu");
+    "(c) 1997, Bernd Johannes Wuebben\n"
+    "(c) 2001, Chris Howells");
+  aboutData.addAuthor("Bernd Johannes Wuebben", I18N_NOOP("Author, Maintainer"), "wuebben@kde.org");
+  aboutData.addAuthor("Chris Howells", I18N_NOOP("User interface re-design"), "howells@kde.org");
   KCmdLineArgs::init( argc, argv, &aboutData );
 
   KApplication a;
