@@ -155,18 +155,18 @@ void CExportDialog::setupDestinationPage( void )
   if( topLayout == 0 ) { return; }
 
   QStringList formatList;
-  formatList.append( i18n("Plain text") );
-  formatList.append( i18n("Html tables") );
-  formatList.append( i18n("Rich text (rtf)") );
-  formatList.append( i18n("C array") );
+  formatList.append( i18n("Plain Text") );
+  formatList.append( i18n("HTML Tables") );
+  formatList.append( i18n("Rich Text (RTF)") );
+  formatList.append( i18n("C Array") );
 
   mDestination.formatCombo = new QComboBox( false, page );
   mDestination.formatCombo->insertStringList( formatList );
   mDestination.formatCombo->setMinimumWidth( fontMetrics().maxWidth()*10 );
-  connect( mDestination.formatCombo, SIGNAL(activated(int)), 
+  connect( mDestination.formatCombo, SIGNAL(activated(int)),
 	   SLOT(formatChanged(int)) );
-  
-  text = i18n("&Format"); 
+
+  text = i18n("&Format:");
   QLabel *label = new QLabel( mDestination.formatCombo, text, page );
   topLayout->addWidget( label );
   topLayout->addWidget( mDestination.formatCombo );
@@ -174,7 +174,7 @@ void CExportDialog::setupDestinationPage( void )
   QHBoxLayout *hbox = new QHBoxLayout();
   topLayout->addLayout( hbox );
 
-  text = i18n("&Destination"); 
+  text = i18n("&Destination:");
   label = new QLabel( text, page );
   hbox->addWidget( label );
  
@@ -199,7 +199,7 @@ void CExportDialog::setupDestinationPage( void )
   hbox = new QHBoxLayout();
   topLayout->addLayout( hbox, 10 );
 
-  mDestination.rangeBox = new QButtonGroup( i18n("Export range"), page );
+  mDestination.rangeBox = new QButtonGroup( i18n("Export Range"), page );
   hbox->addWidget( mDestination.rangeBox );
 
   QButtonGroup *group = mDestination.rangeBox; // convenience
@@ -226,13 +226,13 @@ void CExportDialog::setupDestinationPage( void )
   vbox->addLayout( gbox );
 
   mDestination.fromInput = new QLineEdit( group );
-  text = i18n("&From offset"); 
-  mDestination.fromLabel = new QLabel( mDestination.fromInput, text, group );  
+  text = i18n("&From offset:");
+  mDestination.fromLabel = new QLabel( mDestination.fromInput, text, group );
   gbox->addWidget( mDestination.fromLabel, 0, 0 );
   gbox->addWidget( mDestination.fromInput, 0, 1 );
 
   mDestination.toInput = new QLineEdit( group );
-  text = i18n("&To offset"); 
+  text = i18n("&To offset:");
   mDestination.toLabel = new QLabel( mDestination.toInput, text, group );
   gbox->addWidget( mDestination.toLabel, 1, 0 );
   gbox->addWidget( mDestination.toInput, 1, 1 );
@@ -293,7 +293,7 @@ void CExportDialog::makeHtmlOption( void )
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );  
   if( topLayout == 0 ) { return; }
 
-  text = i18n("Html options. One table per page");
+  text = i18n("HTML Options (one table per page)");
   QLabel *label = new QLabel( text, page );
   topLayout->addWidget( label );
 
@@ -314,29 +314,29 @@ void CExportDialog::makeHtmlOption( void )
   mHtml.lineSpin->setRange( 5, INT_MAX );
   gbox->addWidget( mHtml.lineSpin, 0, 1 );
   
-  text = i18n("&Lines per table");
+  text = i18n("&Lines per table:");
   label = new QLabel( mHtml.lineSpin, text, frame );
   gbox->addWidget( label, 0, 0 );
 
   mHtml.prefixInput = new QLineEdit( frame, "prefix" );
   mHtml.prefixInput->setMinimumWidth( fontMetrics().maxWidth()*10 );
   gbox->addWidget( mHtml.prefixInput, 1, 1 );
-  
-  text = i18n("Filename &prefix (in package)");
+
+  text = i18n("Filename &prefix (in package):");
   label = new QLabel( mHtml.prefixInput, text, frame );
   gbox->addWidget( label, 1, 0 );
 
   QStringList headerList;
   headerList.append( i18n("None") );
-  headerList.append( i18n("Filename with path") );
+  headerList.append( i18n("Filename with Path") );
   headerList.append( i18n("Filename") );
-  headerList.append( i18n("Page number") );
+  headerList.append( i18n("Page Number") );
 
   mHtml.topCombo = new QComboBox( false, frame );
   mHtml.topCombo->insertStringList( headerList );
   gbox->addWidget( mHtml.topCombo, 2, 1 );
 
-  text = i18n("Header &above text");
+  text = i18n("Header &above text:");
   label = new QLabel( mHtml.topCombo, text, frame );
   gbox->addWidget( label, 2, 0 );
 
@@ -344,7 +344,7 @@ void CExportDialog::makeHtmlOption( void )
   mHtml.bottomCombo->insertStringList( headerList );
   gbox->addWidget( mHtml.bottomCombo, 3, 1 );
 
-  text = i18n("&Footer below text");
+  text = i18n("&Footer below text:");
   label = new QLabel( mHtml.bottomCombo, text, frame );
   gbox->addWidget( label, 3, 0 );
 
@@ -385,7 +385,7 @@ void CExportDialog::makeCArrayOption( void )
   QString text;
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );  
 
-  text = i18n("C array options.");
+  text = i18n("C Array Options");
   QLabel *label = new QLabel( text, page );
   topLayout->addWidget( label, 0, AlignLeft );
 
@@ -558,7 +558,7 @@ void CExportDialog::slotOk( void )
   }
   else if( format == option_rtf )
   {
-    QString msg = i18n("Sorry, this format is not yet supported");
+    QString msg = i18n("This format is not yet supported.");
     KMessageBox::sorry( this, msg );
   }
   else if( format == option_carray )
