@@ -1303,7 +1303,7 @@ class CHexBuffer : public QByteArray
     CConversion mEncode;
     bool mCharValid[256];
 
-    char *mColorIndex;
+    unsigned char *mColorIndex;
     char *mPrintBuf;
     bool mLoadingData;
     int  mStartX;
