@@ -766,7 +766,7 @@ void CHexEditorWidget::insertFile( void )
   if( file.isEmpty() )
     return;
 
-  if( file.isLocalFile() )
+  if( !file.isLocalFile() )
   {
     KMessageBox::sorry( 0L, i18n( "Only local files are currently supported." ) );
     return;
