@@ -24,7 +24,7 @@
 #ifndef SubjList_included
 #define SubjList_included
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <kdialogbase.h>
 
 class KListBox;
@@ -42,7 +42,7 @@ signals:
   void entryMoved(int);
 
 public slots:
-  void rebuildList( QList<TextEntry> *);
+  void rebuildList( QPtrList<TextEntry> *);
   void entryChanged(const QString &);
   void select( int );
 
@@ -56,7 +56,7 @@ protected slots:
 
 protected:
   KListBox         *lb_subj;
-  QList<TextEntry> *entrylist;
+  QPtrList<TextEntry> *entrylist;
   int               current;
   bool              highlightflag;
 };
