@@ -53,7 +53,7 @@ WarningConfig::WarningConfig (int t, QWidget * parent, const char *name)
     QVBoxLayout *top_layout = new QVBoxLayout( this, KDialog::marginHint(),
 					       KDialog::spacingHint() );
 	
-    QLabel* explain = laptop_portable::no_power_management_explanation(this);
+    KActiveLabel* explain = laptop_portable::no_power_management_explanation(this);
     top_layout->addWidget(explain, 0);
 
     top_layout->addStretch(1);
@@ -172,6 +172,10 @@ WarningConfig::WarningConfig (int t, QWidget * parent, const char *name)
   my_load(1);
 }
 
+WarningConfig::~WarningConfig()
+{
+  delete config;
+}
 
 void WarningConfig::save()
 {
