@@ -26,7 +26,7 @@
 #include <qstringlist.h>
 #include <qvaluevector.h>
 #include <qregexp.h>
-#include <qapp.h>
+#include <qapplication.h>
 #include <qfileinfo.h>
 #include <qdir.h>
 #include <qimage.h>
