@@ -63,7 +63,7 @@
 #define CPU_NAME(cpu) "Cpu" + QString::number(cpu) + "_options"
 #define CPU_SPEED 1000
 
-KSIM_INIT_PLUGIN(CpuPlugin);
+KSIM_INIT_PLUGIN(CpuPlugin)
 
 CpuPlugin::CpuPlugin(const char *name)
    : KSim::PluginObject(name)
