@@ -59,7 +59,7 @@
 
 #define DISK_SPEED 1000
 
-KSIM_INIT_PLUGIN(DiskPlugin);
+KSIM_INIT_PLUGIN(DiskPlugin)
  
 DiskPlugin::DiskPlugin(const char *name)
    : KSim::PluginObject(name)
