@@ -2,7 +2,7 @@
  *
  *  Copyright (C) 2001  Robbie Ward <linuxphreak@gmx.co.uk>
  *
- *  $Id: ksimfsystem.cpp,v 1.55.2.2 2003/03/14 09:53:19 mlaurent Exp $
+ *  $Id: ksimfsystem.cpp,v 1.55.2.3 2003/07/17 11:02:38 mueller Exp $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -57,7 +57,7 @@
 #include "fsysscroller.h"
 #include <themeloader.h>
 
-KSIM_INIT_PLUGIN(PluginModule);
+KSIM_INIT_PLUGIN(PluginModule)
 
 PluginModule::PluginModule(const char *name)
            : KSim::PluginObject(name)
