@@ -60,7 +60,7 @@ static int mib[] = { CTL_NET, PF_ROUTE, 0, 0, NET_RT_IFLIST, 0 };
 #define NET_UPDATE 1000
 #define LED_UPDATE 125
 
-KSIM_INIT_PLUGIN(NetPlugin);
+KSIM_INIT_PLUGIN(NetPlugin)
 
 NetPlugin::NetPlugin(const char *name)
    : KSim::PluginObject(name)
